@@ -1,6 +1,6 @@
 from abc import ABC
 from GhostScan.CalibrationSession import CalibrationSession
-from Calibrations import RadiometricCalibration
+from GhostScan.Calibrations import RadiometricCalibration
 
 
 class RadiometricCalibSession(CalibrationSession, ABC):
