@@ -11,6 +11,7 @@ from IPython.display import clear_output, Image, display, update_display
 from bokeh.plotting import figure
 from bokeh.io import output_notebook, show, push_notebook
 import PIL
+import os
 
 
 class Internal(Camera, ABC):
@@ -64,20 +65,29 @@ class Internal(Camera, ABC):
         self.cap.set(cv2.CAP_PROP_FRAME_HEIGHT, self.resolution[0])
         self.resolution = resolution
 
-    def getImage(self, name='test', saveImage=True, saveNumpy=True, calibration=False, timeout=5000):
+    def getImage(self, path="", saveImage=True, saveNumpy=True, calibration=False, timeout=5000):
+        if not os.path.exists('CalibrationImages/' + path):
+            os.mkdir('CalibrationImages/' + path)
+        if not os.path.exists('CapturedImages/' + path):
+            os.mkdir('CapturedImages/' + path)
+        if not os.path.exists('CalibrationNumpyData/' + path):
+            os.mkdir('CalibrationNumpyData/' + path)
+        if not os.path.exists('CapturedNumpyData/' + path):
+            os.mkdir('CapturedNumpyData/' + path)
+        
         # Grab current frame
         ret, frame = self.cap.read()
         # Save images
         if saveImage:
             if calibration:
-                cv2.imwrite('CalibrationImages/' + name + '.PNG', cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+                cv2.imwrite('CalibrationImages/' + path + '.PNG', cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
             else:
-                cv2.imwrite('CapturedImages/' + name + '.PNG', cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+                cv2.imwrite('CapturedImages/' + path + '.PNG', cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
         if saveNumpy:
             if calibration:
-                np.save('CalibrationNumpyData/' + name, cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+                np.save('CalibrationNumpyData/' + path, cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
             else:
-                np.save('CapturedNumpyData/' + name, cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
+                np.save('CapturedNumpyData/' + path, cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
         return frame
 
 
