@@ -1,6 +1,6 @@
 from abc import ABC
 from GhostScan.CaptureSession import CaptureSession
-from GhostScan.Projections import Pattern
+from Projections import Pattern
 
 
 class DeflectometryCapture(CaptureSession, ABC):
